/*******************************************************************
 * lipo_inits.c
 * Functions for initializing Lipower controller board
 *
 * Written by Chris Taylor for Sparkfun Electronics, 7/25/08
 ******************************************************************/

#include <msp430x12x2.h>
#include <msp430/usart.h>
#include <msp430/timera.h>
#include <msp430/adc10.h>


/******************************************************************/
int init_clock(void)
{
    /* SYSTEM CLOCK SHOULD BE NOMINALLY 4.9 MHZ */
    DCOCTL |= 0x00e0;       /* set DCO to 7 and MODx to 0 */
    BCSCTL1 |= 0x0007;      /* set RSELx to 7 */
}
/******************************************************************/


/******************************************************************/
int init_SPI(void)
{
    /* Initailize i/o pins */
    P3SEL = 0x000E;         /* set P3.1,2,3 as peripheral */
    P3DIR = 0x0044;         /* set P3.2 as output */

    /* Initialize MSP in SPI mode */
    U0CTL = (SWRST | 0x0000);   /* Hold in reset for initialization*/
    U0CTL |= (CHAR | SYNC);     /* 8-bit char, SPI mode */

    U0TCTL = (CKPL | STC);	/* Reverse clock polarity */

    U0MCTL = 0x0000;            /* Modulation Cont. Reg. to 0 */
    U0ME |= USPIE0;         /* Module Enable */
    U0CTL &= ~(SWRST);      /* Clear reset mode */

    /* Enable USART interrupts */
    U0IE |= (UTXIE0 | URXIE0);  /* TX & RX Interrupt Enable */
}
/******************************************************************/


/******************************************************************/
int init_WDT(void)
{
    /* Initialize WDT */
    WDTCTL = (WDTPW | WDTHOLD);   /* stop WDT */
}
/******************************************************************/


/******************************************************************/
int init_ACLK(void)
{
    /* Turn on ACLK */
    BCSCTL1 &= ~(0x0030); /* set divider to 1 */
    _BIC_SR(OSCOFF);    /* clear OSCOFF */
}
/******************************************************************/


/******************************************************************/
int init_timerA(void)
{
    /* interrupt at 1/10 sec */
    init_ACLK;      /* start ACLK */
    TACCR0 = 0;     /* Stop the timer */
    TACTL = (TASSEL_1 | ID_0 | TAIE);  /* Use ACLK, up mode */
    TACTL |= MC_1;
    TACCR0 = 0x0ccd;           /* Start timer */   // 0x0ccd for 1/10 sec
    /* Remember to reset TAIV in interrupt handler */
}
/******************************************************************/


/******************************************************************/
int init_GPIO(void)
{
	//Initialize inputs and outputs
	P1DIR = 0x0010;
	P2DIR = 0x0000;
	P3DIR = 0x0000;

	P2DIR |= 0x003C; 
	P3DIR |= 0x0040; 

	// Set all outputs to low
	P1OUT = 0x0000;
	P2OUT = 0x0000;
	P3OUT = 0x0000;
}
/******************************************************************/


/******************************************************************/
int init_buttons(void)
{
}
/******************************************************************/


/******************************************************************/
int init_ADC10(void)
{
	ADC10CTL0 = SREF_1 | REFON | ADC10IE;
	ADC10AE = 0x01;
	ADC10CTL0 |= ADC10ON;

}
/******************************************************************/
